# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from avido import Avido, AsyncAvido
from avido.types import (
    Document,
    DocumentListResponse,
)
from tests.utils import assert_matches_type
from avido.pagination import SyncOffsetPagination, AsyncOffsetPagination

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestDocuments:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: Avido) -> None:
        document = client.documents.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: Avido) -> None:
        document = client.documents.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
            metadata={"foo": "bar"},
            original_sentences=["This is the first sentence.", "This is the second sentence."],
            parent_id="456e4567-e89b-12d3-a456-426614174000",
            scrape_job_id="321e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: Avido) -> None:
        response = client.documents.with_raw_response.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: Avido) -> None:
        with client.documents.with_streaming_response.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(Document, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: Avido) -> None:
        document = client.documents.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: Avido) -> None:
        response = client.documents.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: Avido) -> None:
        with client.documents.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(Document, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: Avido) -> None:
        document = client.documents.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: Avido) -> None:
        document = client.documents.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            assignee="user_987654321",
            content="This updated document describes the API endpoints...",
            metadata={"foo": "bar"},
            original_sentences=["This is the updated first sentence.", "This is the updated second sentence."],
            parent_id="456e4567-e89b-12d3-a456-426614174000",
            status="APPROVED",
            title="Updated API Documentation",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: Avido) -> None:
        response = client.documents.with_raw_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: Avido) -> None:
        with client.documents.with_streaming_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(Document, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update(self, client: Avido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.documents.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: Avido) -> None:
        document = client.documents.list()
        assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_list_with_all_params(self, client: Avido) -> None:
        document = client.documents.list(
            assignee="user_123456789",
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            parent_id="456e4567-e89b-12d3-a456-426614174000",
            scrape_job_id="321e4567-e89b-12d3-a456-426614174000",
            skip=0,
            status="APPROVED",
        )
        assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: Avido) -> None:
        response = client.documents.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = response.parse()
        assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: Avido) -> None:
        with client.documents.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = response.parse()
            assert_matches_type(SyncOffsetPagination[DocumentListResponse], document, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncDocuments:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
            metadata={"foo": "bar"},
            original_sentences=["This is the first sentence.", "This is the second sentence."],
            parent_id="456e4567-e89b-12d3-a456-426614174000",
            scrape_job_id="321e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.create(
            assignee="user_123456789",
            content="This document describes the API endpoints...",
            status="DRAFT",
            title="API Documentation",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(Document, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.retrieve(
            "123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(Document, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.update(
            id="123e4567-e89b-12d3-a456-426614174000",
            assignee="user_987654321",
            content="This updated document describes the API endpoints...",
            metadata={"foo": "bar"},
            original_sentences=["This is the updated first sentence.", "This is the updated second sentence."],
            parent_id="456e4567-e89b-12d3-a456-426614174000",
            status="APPROVED",
            title="Updated API Documentation",
        )
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(Document, document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.update(
            id="123e4567-e89b-12d3-a456-426614174000",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(Document, document, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update(self, async_client: AsyncAvido) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.documents.with_raw_response.update(
                id="",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.list()
        assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_list_with_all_params(self, async_client: AsyncAvido) -> None:
        document = await async_client.documents.list(
            assignee="user_123456789",
            limit=25,
            order_by="createdAt",
            order_dir="desc",
            parent_id="456e4567-e89b-12d3-a456-426614174000",
            scrape_job_id="321e4567-e89b-12d3-a456-426614174000",
            skip=0,
            status="APPROVED",
        )
        assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncAvido) -> None:
        response = await async_client.documents.with_raw_response.list()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        document = await response.parse()
        assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncAvido) -> None:
        async with async_client.documents.with_streaming_response.list() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            document = await response.parse()
            assert_matches_type(AsyncOffsetPagination[DocumentListResponse], document, path=["response"])

        assert cast(Any, response.is_closed) is True
